#!/usr/bin/sh

#
# The source here is entirely from an openssl-0.9.* distribution except for:
#
# - openssl-0.9.sh (this file)
# - openssl-0.9.depend (depend file for build script)
# - openssl-0.9-patches
#

set -x
set -e

# Apply patches.
[ -f openssl-0.9-been-patched ] || {
	/usr/bin/patch -p1 -i openssl-0.9-patches
	date >openssl-0.9-been-patched
}

# Define prefix and openssl dir -- use relative pathnames.
PREFIX=usr
OPENSSLDIR=etc/ssl

# Configure -- enable shared library creation, and libz.
./config \
	--prefix=/${PREFIX} --openssldir=/${OPENSSLDIR} \
	shared zlib-dynamic

#
# Make libraries and install header files and libraries in xenv.
# Override hardcoded CC and AR in Makefiles.
#
${MAKE} CC=${CC} AR="${AR} ${ARFLAGS}" \
	INSTALL_PREFIX=${TOOLS} install_hdrs install_libs

# Now make everything and install in ${ROOT}/${MACH}.
${MAKE} CC=${CC} AR="${AR} ${ARFLAGS}" \
	INSTALL_PREFIX=${ROOT}/${MACH} install

#
# Move man pages to Unix standard directories.
# We are not modifying Makefile.org since this is UnixWare specific change.
#

# Move all files from directory $1 to $2.
_mv()
{
	[ ! -d $2 ] && mkdir -p $2
	/usr/bin/ls $1 | /usr/bin/xargs -i /usr/bin/mv -f $1/{} $2/{}
}

cd ${ROOT}/${MACH}
_mv ${OPENSSLDIR}/man/man1 ${PREFIX}/man/man.1
_mv ${OPENSSLDIR}/man/man3 ${PREFIX}/man/man.3
_mv ${OPENSSLDIR}/man/man5 ${PREFIX}/man/man.5
_mv ${OPENSSLDIR}/man/man7 ${PREFIX}/man/man.7
